###
#' @title Brass polynomial
#' @description \code{Brass polynomial} calculates Brass polynomial
#' 
#' @details \eqn{mx = c(x - s)(s + w - x)^2}
#' 
#' @param c constant
#' @param mx.range First and last age at reproduction (s and w)
#' @return vector with Brass values.
#' @author Frank PG Princee 
#' @references Timothy B. Gage(1995)
#' @keywords internal
#' 
Brass.polynomial <- function(c,mx.range)
{
  s <- mx.range[1]
  l <- mx.range[2]
  x <- s:l
  cat(s,l,x,"\n")
  mx.poly <- c*(x-s)*((l-x)^2)
 
  return(mx.poly)
}

###
# Brass polynomial: 
# mt =c(t−s)(s+w−t)^2
# where t is age, s is the age at first reproduction, 
# w is the length of the reproductive period, c is a coefficient describing the level of fertility, 
# and mt = 0.0 when t < s or t > s + w. 
#
fitBrass <- function( initialpar = c(0.1), data, Method = "Nelder-Mead", ...) 
{
  fBrass <- function(z, rASFR) {
    k <- length(rASFR)
    res <- sum((rASFR - Brass.polynomial(z[1], k))^2)
    RMSE <- sqrt(res/nc)
    return(RMSE)
  }
  xdata <- data[!is.na(data)]
  rBrass <- optim(initialpar, fBrass, gr = NULL, xdata, method = Method, ...)
  return(c(rBrass$par, rBrass$value, rBrass$convergence))
}






