###
#' @title Hadwiger fecundity function
#' @description \code{Hadwiger function} calculates Hadwiger function
#' 
#' @details mx = a * b/c * (c/x)^1.5 * exp(-b^2 * (c/x + x/c - 2))
#' 
#' @param a parameter a (default: 3.4)
#' @param b parameter b (default: 2.5)
#' @param c parameter c (default: 22.2)
#' @param k Number of classes 
#' @return vector with Hadwiger values.
#' @author Frank PG Princee
#' @references Hoem
#' @family fecundity
#' @keywords internal
#' 
studbook.Hadwiger <- function(a = 3.4, b = 2.5, c = 22.2,k)
{
    ages <- 1:(k-1)     # youngest class > 0
    rval <- (a * b)/c * (c/ages)^1.5 * exp(-b^2 * (c/ages + ages/c - 2))
    rval <- c(0,rval)
    names(rval)  <- 0:(k-1)
    return(rval)  
}


###
#' @title Fit Hadwiger fecundity function
#' @description \code{fitHadwiger} fits the Hadwiger function
#' @param initialpar initial parameters  
#' @family fecundity
#' 
fitHadwiger <- function( initialpar = c(0.1,2.5,22.2), data, Method = "Nelder-Mead", ...) 
{
  
  fHadwiger <- function(z, rASFR) {
    nc <- length(rASFR)
    res <- sum((rASFR - studbook.Hadwiger(z[1], z[2], z[3],nc))^2)
    RMSE <- sqrt(res/nc)
    return(RMSE)
  }
  xdata <- data[!is.na(data)]
  rHadwiger <- optim(initialpar, fHadwiger, gr = NULL, xdata, method = Method, 
              ...)
  return(c(rHadwiger$par, rHadwiger$value, rHadwiger$convergence))
}








