###
#' @title Annual census
#' 
#' @description \code{studbook.census} plots annual census data and calculates growth rates. 
#' 
#' @details plot, growth rate, sex-ratio
#' 
#' @param first first year of census. NULL refers to first year in data (default NULL) 
#' @param last last year of census. NULL refers to last years data (default NULL)
#' @param analyse options are \code{"growth"} for growth rates
#' and/or \code{"sexratio"} for analysing sex-ratio. (default: both analyses)  
#' @author Frank Princee
#' @family census
#' @examples 
#' \dontrun{
#' studbook.census()            # Entire historical census data of total, male and female population
#' studbook.census(1977)        # Census from 1997 and onwards
#' studbook.census(1977,1996)   # Census from 1977 until 1996
#' }
#'  
#' @export 
#' 
studbook.census <- function(first = NULL,last = NULL,analyse=c("growth","sexratio")) 
{
  studbook.screenTitle('Census')
  
  # Read data and create time series for all, males and females
  census.ts <- census.read('census',first,last)
  
  if (is.null(census.ts)) {
    stop("No census data")
  }
  analyse <- match.arg(analyse,several.ok=TRUE)
  
  print(census.ts)
  census.plot(census.ts,'census') 
  
  if (is.element("growth",analyse)) {
    #Group names
    group.names <- colnames(census.ts)
    groups      <- length(group.names)
   
    for (group in 1:(groups-1) ){
      census.growth(census.ts[,group],group.names[group])
    }
  }
  
  if (is.element("sexratio",analyse)) {
    census.sexratio(census.ts,'census') 
  }
}






