###
#' @title Census-age plot
#' @description \code{studbook.censusAge} combines multiple age pyramids and census in a single graph
#' @author Frank PG Princee
#' @export
#' 
studbook.censusAge <- function(first=NULL,last=NULL,monitor="0101") 
{
  census.ts <-  census.read('census',first,last)
  
  studbook.openOutput("census_age")
  
  studbook.caption("Census and age distibution","")
  plot(census.ts[,'ALL'], xlab="year", ylab="count",main="",
       col='black',type='l',lwd=2,lty=1)
  studbook.title("Census and age distribution")    
  
  startyear <- min(time(census.ts))
  endyear   <- max(time(census.ts))
  
  ages1 <- age.read(date=paste(startyear,monitor,sep=""),truncate=TRUE)
  ages2 <- age.read(date=paste(endyear,monitor,sep=""),truncate=TRUE)
  
  if( is.null(ages1) || is.null(ages2) ) { 
    stop("No age data on females, males and/or unknown sex.")
  }
  
  ages1 <- age.unknown(ages1,0.5)
  ages2 <- age.unknown(ages2,0.5)
  
  size1 <- max(ages1[,'M'],ages1[,'F'])   
  size1 <- ceiling(size1)
  
  size2 <- max(ages2[,'M'],ages2[,'F'])   
  size2 <- ceiling(size2)
  
  max.size <- max(size1,size2)
  max.size <- ceiling(max.size)
  
  par(fig=c(0.12, 0.52, 0.2,0.8), new=TRUE,ps=9)
  plotrix::pyramid.plot(ages1[,'M'],ages1[,'F'], main=startyear,
                        labels=rep("",nrow(ages1)),gap=0.0,
                        top.labels =NA,unit=c("",""),
                        xlim=c(max.size,max.size),
                        laxlab=c(0,max.size),
                        raxlab=c(0,max.size),
                        lxcol='gray',rxcol='gray') 
  
  
  
  size2 <- max(ages2[,'M'],ages2[,'F'])   
  size2 <- ceiling(size2)
  par(fig=c(0.58, 0.98, 0.2,0.8), new=TRUE,ps=9)
  plotrix::pyramid.plot(ages2[,'M'],ages2[,'F'], main=endyear,
                        labels=rep("",nrow(ages2)),gap=0.0,
                        top.labels =NA,unit=c("",""),
                        xlim=c(max.size,max.size),
                        laxlab=c(0,max.size),
                        raxlab=c(0,max.size),
                        lxcol='gray',rxcol='gray') 
  
  par(fig=c(0,1,0,1),ps=12)
  
  studbook.closeOutput()
}