###
#' @title Plot overview of census and events 
#' 
#' @description \code{studbook.census_overview} plots annual census, births, deaths, and migration
#' 
#' 
#' @details plot, growth rate, sex-ratio
#' 
#' @param first first year of census. NULL refers to first year in data (default NULL) 
#' @param last last year of census. NULL refers to last years data (default NULL)
#' @param sex Single or multiple sex groups. Valid codes are \code{"all","male","female","unknown"}
#' @author Frank Princee
#' @examples 
#' \dontrun{
#' studbook.census_overview()                # Entire historical census and census events
#' studbook.census_overview(1977,sex='male') # Census-style data fro males from 1997 and onwards
#' studbook.census_overview(1977,1996)       # Census from 1977 until 1996
#' }
#' 
#' @family census
#' @export 
#' 
studbook.census_overview <- function(first = NULL,last = NULL, 
                                sex=c("all","male","female","unknown")) 
{
  studbook.screenTitle('Census and census events')
  sex <- match.arg(sex)
  if ( is.element(sex,c("male","female"))) {
     sex <- paste(sex,'s',sep='')
  }
  sex <- toupper(sex)   # Column names are in upper case
  
  # Read data and create time series for requested sex
  census.ts  <- census.read('census',first,last)
  birth.ts   <- census.read('birth',first,last)
  death.ts   <- census.read('death',first,last)
  import.ts  <- census.read('immigration-all',first,last)
  export.ts  <- census.read('emigration',first,last)
  
  if (sex == 'ALL') {
    sexpop <- 'N'
  } else {
    sexpop <- paste('N',substr(sex,1,1),sep='')
  }
  txt <- paste("log(",sexpop,")",sep='')
  studbook.openOutput("census_overview")
  plot(census.ts[,sex],xlab='Year',ylab=txt,log='y',cex=0.6,lty=1)
  
  lines(birth.ts[,sex],lty=1)
  points(birth.ts[,sex],pch=1,cex=0.6)
  
  lines(death.ts[,sex])
  points(death.ts[,sex],pch=4,cex=0.6)
  
  lines(import.ts[,sex],lty=1)
  points(import.ts[,sex],pch=5,cex=0.6)
  
  #lines(export.ts[,sex],lty=5,lwd=2)
  abline(h=c(2,5,10,20,50,100),lty='dotted')
  studbook.closeOutput()
}






