###
# Package : studbookR
# 
# Copyright (c) 2011 Frank PG Princee, All rights reserved
#

###
#' @title Genetic drift in ideal populations
#' @description \code{studbook.drift} estimates loss in gene diversity for given N and generations
#' @param Ne Single value or list with effective population size 
#' @param G Number of generations (default:10)
#' @param N0 Single value or vector with number of founders to estimate founder effect (default:NULL)
#' @author Frank PG Princee
#' @export
#' 
studbook.drift <- function(N,G=25)
{
  group <-  length(N)
  He    <-  matrix(nrow=G+1,ncol=group)

  colnames(He) <- N
  rownames(He) <- 0:G

  He[1,] <- rep(1,group)
  
  for (x in 1:length(N)) {
    He[1,x] <- 1- (1/(2*N[x]))  # Founder effect

    # Genetic drift
    for (t in 1:G) {
       He[t+1,x] <- (1 - (1/(2*N[x]))) * He[t,x]
    }
  }
  
  studbook.openOutput("genetic_drift")
  matplot(He,type='l',lty='solid',ylim=c(0,1),lwd=1,col='black',
          xlab="Generations",ylab="Wild gene diversity")
  
  # Labels
  x <- 0.4 * G
  text(x=x,y=He[x,],adj=c(0,-0.5),cex=0.8,labels=paste("N=",colnames(He),""))
   
  studbook.closeOutput()
}
