#
# Package : studbookR
# 
# Copyright (c) 2011 Frank PG Princee, All rights reserved
#

###
#' @title Age at first breeding in males and females
#' 
#' @param truncate Percentage of left and right truncation
#' @param explore Explore effects of sample size and truncation (default: FALSE)
#' @param bootstrap: bootstrap on mean (default: FALSE)
#' @param file_name Basic name of data file (default: \code{"firstbreeding"})
#' @author Frank PG Princee
#' @export
#' 
studbook.firstBreeding <- function(truncate=0.0,explore=FALSE,bootstrap=FALSE,
                                   file_name="firstbreeding")
{
  
  studbook.screenTitle("Age at first reproduction")
  
  male   <-studbook.read(file_name,sex='male')[,'AGE']
  female <-studbook.read(file_name,sex='female')[,'AGE']
  
  if (is.null(male) || is.null(female)) {
    stop("No data on first reproduction in males and/or females.")
  }
  
  male   <- sort(male)
  female <- sort(female)
  
  studbook.openOutput('firstbreeding')
  if (explore) {
    distribution.sample(female,c(10,50,100,250),
                        main_title='Random samples of age at 1st reproduction', 
                        'Age in days') 
    distribution.exploreEnds(female,levels=c(0.1,0.05,0.01),
                             side='left',"Age at 1st reproduction (males)","Age in days") 
    distribution.exploreEnds(female,levels=c(0.1,0.05,0.01),
                             side='right',"Age at 1st reproduction (females)","Age in days") 
  } 
  
  male   <- sample.truncate(male,truncate,'both') 
  female <- sample.truncate(female,truncate,'both') 
  
  
  studbook.summary( male,long=TRUE,CV=FALSE,title="Age at 1st reproduction (males)")
  studbook.summary( female,long=TRUE,CV=FALSE,title="Age at 1st reproduction (females)")
  
  
  distribution.initGraphs(FALSE)
  distribution.selectGraph('histogram',TRUE)
  
  max.data <- max(max(male),max(female) )
  age_breaks <- seq(0,max.data + 366,365.25)
  
  naturalhistory.plot(male,  'Age at 1st reproduction (males)',age_breaks)
  naturalhistory.plot(female,'Age at 1st reproduction (females)',age_breaks)
  
  #DAYS
  naturalhistory.compareSexes(male,female)    
  
  # Bootstrap of mean
  if (bootstrap) {
    studbook.bootstrap(data=male,statistic=mean.fun,main_title="First reproduction (males)")
    studbook.bootstrap(data=female,statistic=mean.fun,main_title="First reproduction (females)")
  }
  studbook.closeOutput()
  
  return(TRUE)
}


