###
#' @title Plot founder representation
#' 
#' @author Frank PG Princee
#' @export
#' 
studbook.founders <- function()
{
 
  studbook.screenTitle("Founder representation")
  
  founders           <- studbook.read('founders-group')  
  founders           <- t(founders)         # Swap rows and columns
  colnames(founders) <- founders[1,]        # First row has column headers

  # Remove first row with column names
  founders[1,] <- NA                                                              
  founders     <- na.omit(founders)
  
  # Remove trailing white (as data are imported as characters)
  founders[,'CONTRIBUTION'] <- as.double(founders[,'CONTRIBUTION'])
  founders[,'FRACTION']     <- as.double(founders[,'FRACTION'])
  founders[,'DESCENDANTS']  <- as.integer(founders[, 'DESCENDANTS']) 
  
  founders  <- founders[order(as.double(founders[,'FRACTION'])),]   # Order on fraction 
  potential <- subset(founders,as.double(founders[,'FRACTION']) <= 0.0)
  founders <- subset(founders,as.double(founders[,'FRACTION']) > 0.0)
  equal_fraction <- mean(as.double(founders[,'FRACTION']))
  
  print(founders)
  cat("\n")
  cat("Number of founders          :",nrow(founders),"\n")
  cat("Equal founder representation:",equal_fraction,"\n")
  cat("Number of potential founders:",nrow(potential),"\n")
  cat("Known contribution:          ",sum(as.double(founders[,'FRACTION'])),"\n")
  
  # Plot founder representation as fraction of population
  if (!studbook.plot()) {
    invisible(FALSE)
  }
  studbook.openOutput('founders')
  main_title <- "Founder representation"
  sub_title  <- "UNKNM=unknown male, UNKNF=unknown female; dashed line is equal distribution."
  studbook.caption(main_title,sub_title)
  
  midpoints <- barplot(as.double(founders[,'FRACTION']),names.arg=rownames(founders),
                       ylab='Fraction',cex.names=0.5,las=2)
  
  abline(h=equal_fraction,lty='dashed')
  studbook.title(main_title)
  studbook.closeOutput()
  
  invisible(TRUE)
}




