###
#' @title Calculate gene diversity at single locus from allele frequencies
#' @author Frank PG Princee
#' @param vector with allele frequencies (default: c(0.5,0.5))
#' @return gene diversity(expected heterzygosity)
#' @export
#' 
geneDiversity <- function(alleles=c(0.5,0.5))
{
  total <- sum(alleles)
  if (total < 1) {
    alleles <- c(alleles,1-total)
  }
  gene_identity <- 0.0
  
  for (x in 1:(length(alleles))) {
    gene_identity <- gene_identity + alleles[x]^2
  }
  return(1.0 - gene_identity)
}
  

founder.variation <- function(N=2)
{
  frequency <- 1/(founders * 2)
  alleles   <- rep(frequency,(founders * 2))
  
  return( 1 - 1/(2*N)) 
}


###
#' @title Analyze and plot gene drop runs
#' @author Frank PG Princee
#' @family genetics
#' @export
#' 
studbook.genedrop <- function()
{
  genedrop  <- studbook.read('genedrop')  
  
  if (is.null(genedrop)) { 
    stop("No Genedrop simulation data.")
  }
  studbook.screenTitle('Genedrop simulation data')
  distribution.setType("percentage")
  
  studbook.openOutput('genedrop')
  distribution.initGraphs(FALSE)
  distribution.selectGraph('HISTOGRAM',TRUE)
  
  xlabel <- 'Heterozygosity'
  distribution.analyse(genedrop$HETEROZYGOSITY,bar_breaks='Sturges',main_title='Gene drop simulation',xlabel=xlabel)
   
  xlabel <- 'Gene diversity'                  
  distribution.analyse(genedrop$GENE_DIVERSITY,bar_breaks='Sturges',main_title='Gene drop simulation',xlabel=xlabel)
  
  xlabel <- 'Genome diversity'
  distribution.analyse(genedrop$GENOME,bar_breaks='Sturges',main_title='Genome drop simulation',xlabel=xlabel)
  
  studbook.closeOutput()  
  
  
  
}




