###
#' @title Plot confidence intervals 
#' @description \code{plot.CI} plots confidence intervals of mean.
#' @details Confidence intervals are plotted as segments. The upper and lower 
#' limits must be provided by the calling function. 
#' 
#' @param data_set Data frame that includes the following columns (in same 
#' order): observed value, mean, lower and upper confidence limits.
#' @author Frank PG Princee
#' @family studbook graphics
#' @export
#'  
plot.CI <- function(data_set)
{
  points(data_set[,1:2],pch=20,cex=0.75)
  segments(data_set[,1],data_set[,3],data_set[,1],data_set[,2])
  segments(data_set[,1]-0.25,data_set[,3],data_set[,1]+0.25,data_set[,3])
  segments(data_set[,1],data_set[,4],data_set[,1],data_set[,2])
  segments(data_set[,1]-0.25,data_set[,4],data_set[,1]+0.25,data_set[,4])
}

###
#' @title Plot second Y axis
#' @description \code{Y2.axis} plots graph with two different Y-axis
#' @param dataX data for X-axis
#' @param dataY1 Data for first Y-axis
#' @param dataY2 Data for second Y-axis
#' @param xlabel Text for X-axis (default X1)
#' @param ylabel Vecor with text for both y-axes (default: c("Y1","Y2") )
#' @param graphtype vector with \code{type} values (default: c("b","b) )
#' @param pointshape vector with \code{pch} values (default: c(21,22))
#' @param linestyle vector with \code{lty} values (default: c('dashed','dotdashed') )
#' @param linescolor vector with \code{col} values (default: c('black','black') )
#' @author Frank PG Princee
#' @note vectors dataX1, dataY1 and dataY2 must contain the same number of elements.
#' @family studbook graphics
#' @export
#' 
Y2.axis <- function(dataX,dataY1,dataY2,xlabel='X1',ylabel=c('Y1','Y2'),
                   graphtype=c("b","b"),pointshape=c(21,22),
                   linestyle=c('dashed','dotdash'),
                   linecolor=c("black","black"))
{
  old.par <- par(mar=c(5,4,4,5)+.1)
  xlabel <- firstCap(xlabel)
  ylabel <- firstCap(ylabel)
  plot(dataX,dataY1,type=graphtype[1],pch=pointshape[1],cex=0.8,lty=linestyle[1],col=linecolor[1],
       xlab=xlabel,ylab=ylabel[1])
  par(new=TRUE)
  plot(dataX, dataY2,type=graphtype[2],pch=pointshape[2],cex=0.8,lty=linestyle[2],col=linecolor[2],xaxt="n",yaxt="n",
       xlab="",ylab='')
  axis(4)
  mtext(ylabel[2],side=4,line=3)
  par(old.par)
}


###
#' @title Plot quantiles 
#' @description \code{plot.quantiles} plots user defined quantiles
#' @details The quantiles are plotted as vertical lines in iether dotted (default) or
#' user-defined line style
#'
#' @param quantiles vector with quantiles of distribution 
#' @param lty Line style
#' @author Frank PG Princee
#' @family studbook graphics
#' @export
#' 
plot.quantiles <- function(quantiles,lty='dotted')
{        
  abline(v=quantiles,lty=lty,lwd=2)
}

###
#' @title Plot mean
#' @description \code{plot.mean} plots mean value 
#' @details The mean is plotted as a vertical line in either dashed (default) or
#' user-defined line style
#'
#' @param mean Mean of distribution data
#' @param lty Line style
#' @author Frank PG Princee
#' @export
#' @family studbook graphics
#'  
plot.mean <- function(mean,lty='dashed')
{
  abline(v=mean,lty=lty,lwd=1)             
}