###
# Package : studbookR
# 
# Copyright (c) 2011 Frank PG Princee, All rights reserved
#

###
#' @title Immigration
#' @description \code{studbook.immigration} analyses immigration (imports).
#' 
#' @details Assign \code{NULL} to arguments \code{first} and/or \code{last} to include the oldest and
#' most recent data, respectively. 
#' 
#' @param first First year of death census (default = NULL) 
#' @param last Last year of death (default = NULL)
#' @param origin options: \code{"all"} or \code{"wildborn"} (default: all)
#' @author Frank PG Princee
#' @seealso \code{\link{census.plot}}, \code{\link{census.rates}}, \code{\link{studbook.births}}, 
#' \code{\link{studbook.census}}, \code{\link{studbook.deaths}}, 
#' \code{\link{studbook.emigration}}
#' @examples
#' \dontrun{
#' studbook.immigration(origin='all')            # all imports
#' studbook.immigration(origin='wildborn')       # imports from the wild
#' studbook.immigration(first=1977,origin='all') # all imports in 1977 and onwards
#' studbook.immigration(first=1977,last=1997)    # imports from 1977 until 1996 (20 years)
#' 
#' }
#' @family census
#' @export
#
studbook.immigration <- function(first=NULL, last=NULL, origin=c("all","wildborn") )
{
  origin <- match.arg(origin)
  import.ts <- census.read(paste('immigration',origin,sep='-'),first,last)
  if (is.null(import.ts)) {
    warning("No immigration data.")
    return(FALSE)
  }
  
  studbook.screenTitle('Census of imports')
  
  census_type <- paste("immigration",origin,sep='.')
  studbook.caption(census_type) 
  print(import.ts)
  census.plot(import.ts,census_type)
  
  return(TRUE)
}


###
#' @title Emigration
#' @description \code{studbook.emigration} analyses emigration (exports).
#' 
#' @details Assign \code{NULL} to arguments \code{first} and/or \code{last} to include the oldest and
#' most recent data, respecitively. 
#' 
#' @param first First year of census (default = NULL) 
#' @param last Last year of census (default = NULL)
#' @param file_name Base name of data file (default: \code{"emigration"})
#' @author Frank PG Princee
#' @seealso \code{\link{census.plot}}, \code{\link{census.rates}}, \code{\link{studbook.births}}, 
#' \code{\link{studbook.census}}, \code{\link{studbook.deaths}}, 
#' \code{\link{studbook.emigration}}
#' @examples
#' \dontrun{
#' studbook.emigration()                        # all emigrants
#' studbook.emigration(first=1977,last=1997)    # imports from 1977 until 1996 (20 years)
#' 
#' }
#' @family census
#' @export
#
studbook.emigration<-function(first=NULL, last=NULL,file_name="emigration") 
{
  
  export.ts <- census.read(file_name,first,last)
  if (is.null(export.ts)) {
    warning("No emigration data")
    return(FALSE)
  }
  
  studbook.screenTitle('Census of emigration') 
  studbook.caption("Census of emigration") 
  print(export.ts)
  census.plot(export.ts,'emigration')
}
