###
# Package : studbookR
# Module  : studbook_moon
# Copyright (c) 2012 Frank PG Princee, All rights reserved
#


###
#' @title Evaluate pattern in moon segment 
#' @param moon_segment vector with moon segments.
#' @param main_title main title for figure caption.
#' @author Frank PG Princee
#' @family lunar cycle
#' @keywords internal
#' 
moon.segment <- function(moon_segment,main_title)
{
  if (length(moon_segment) <= 0 ) {
    stop("No moon segments provided.")
  }
  
  phase.names <- c('New','Waxing cresent','First quarter',
                   'Waxing gibbous','Full','Waning gibbous',
                   'Last quarter','Waning crescent')
  moon.table <- table(moon_segment)
  moon.table <- as.data.frame(moon.table)
  colnames(moon.table) <- c('SEGMENT','FREQUENCY')
  studbook.caption(main_title)
  barplot(height=moon.table$FREQUENCY,names.arg=phase.names,main='',xlab="Moon phase",
          ylab="Frequency")
  studbook.title(main_title)
  cat('\n')
  print(moon.table)
  return(TRUE)
  
}

###
#' @title Evaluate pattern in moon phase
#' @param moon_phase vector with moon phases.
#' @param main_title main title for figure caption.
#' @author Frank PG Princee
#' @family lunar cycle 
#' @keywords internal
#' 
moon.phase <- function(moon_phase,main_title)
{
  if (length(moon_phase) <= 0 ) {
    stop("No moonphase provided.")
  }
  
  moon.table <- table(moon_phase)
  moon.table <- as.data.frame(moon.table)
  colnames(moon.table) <- c('PHASE','FREQUENCY')

  studbook.caption(main_title)
  plot(x=as.numeric(moon.table$PHASE),y=moon.table$FREQUENCY,type='h',main='',xlab="Moon phase [0..1]",
       ylab="Frequency")
  studbook.title(main_title)
  cat('\n')
  print(moon.table);
  return(TRUE)
  
}


###
#' @title Lunar cycle and births
#' @description \code{moon.birth} will analyse the lunar cycle and births
#' @param sex Sex group \code{'all','female','male','unknown'} (default: \code{'all'})
#' @param file_name Base name of data file (default: \code{"birth_season"})
#' @family lunar cycle
#' @export
#' 
moon.birth <- function(sex=c('all','female','male','unknown'),file_name="birth_season")
{  
  studbook.screenTitle("Lunar cycle and births")
  
  studbook.openOutput('lunar')
  sex <- match.arg(sex)
  
  for (group in sex) {
    births <- studbook.read(file_name,sex=group)
    info <- paste("Lunar cycle in births (",group,")",sep="")
    moon.segment(births[,'SEGMENT'],info)
    #moon.phase(births[,'PHASE'],info)
  }
  
  studbook.closeOutput()
}


###
#' @title Lunar cycle and litter date
#' @description \code{moon.litter} will analyse the lunar cycle and litter dates
#' @param file_name Base name of data file (default: \code{"litter_season"})
#' @family lunar cycle
#' @export
#' 
moon.litter <- function(file_name="litter_season")
{  
  studbook.screenTitle("Lunar cycle and litter dates")
  
  studbook.openOutput('lunar')
  
  births <- studbook.read(file_name,sex='all')
  info <- "Lunar cycle in litter dates"
  moon.segment(births[,'SEGMENT'],info)
  #moon.phase(births[,'PHASE'],info)

  studbook.closeOutput()
}



###
#' @title Effect of lunar cycle  on birth 
#' @family lunar cycle
#' @export
#
studbook.moon <- function(analysis=c('birth','litter'),sex=c('all','female','male','unknown'))
{
  analyses <- match.arg(analysis)
  sex      <- match.arg(sex, several.ok = TRUE)
  if (analysis == 'birth') {
    moon.birth(sex)
  } else if (analysis == 'litter') {
    moon.litter()
  }
}
