###
# Package : studbookR
# 
# Copyright (c) 2011 Frank PG Princee, All rights reserved
#



###
#' @title Plots histogram of natural history data
#' @description \code{naturalhistory.plot} plots age--related natural history data
#' 
#' @details This function uses \code{distribution.plot} to plot a histogram of age--related 
#' natural history data e.g. age at death, age at reproduction or interbirth interval.
#' 
#' @param sample vector with sample data
#' @param main_title main title above figure
#' @param breaks a vector with breaks or model as used by the function \code{hist} (default "Sturges")
#' @param unit time unit (default "days")
#' @author Frank PG Princee
#' @family natural history
#' @seealso \code{\link{distribution.plot}}
#' @keywords internal
#'      
naturalhistory.plot <- function(sample,main_title="Natural history",
                                breaks="Sturges",unit="day")
{
  if (studbook.plot()) {
    distribution.plot(sample,main_title,xlabel=paste0('Age (in ',unit,'s)' ),
                      breaks,leftPoints=min(data_set) )
  }
}


###
#' @title Compares natural history data of males and females.
#' 
#' @details The non--parametric Wilcoxon (Mann-Whitney) test is used to determine 
#' whether male and females samples do not differ. A Q-Q plot of males versus females 
#' is plotted.
#' 
#' @param sample.males vector with male data
#' @param sample.females vector with female data
#' @param alpha signifance level (default = 0.05)
#' @author Frank PG Princee
#' @seealso \code{link{wilcoxon.test}}
#' @family natural history
#' @keywords internal
#'   
naturalhistory.compareSexes <- function(sample.males,sample.females,alpha = 0.05)
{
  #Q-Q Plot
  
  wilcoxon.test(sample.males,sample.females,main_title="Compare sexes",alpha)
  
  if (studbook.plot()) {
    
    #Note no truncation at head or tail
    main_title <- paste("Q-Q plot male/female")
    comment    <- "Dashed line refers to no differences."
    studbook.caption(main_title,comment)
    
    qq <- qqplot(sample.males,sample.females,main="",
                 xlab='Males (days)',ylab='Females (days)')
    qqline(qq$y,col="green")
    abline(0,1,col="black",lty="dashed")    
    studbook.title(main_title) 
  }
}


