###
# Package : studbookR
# 
# Copyright (c) 2011 Frank PG Princee, All rights reserved
#

###
# Global variables
#
neonatal_age <-  30.0 # 30 days 

###
#' @title Set neontal age 
#' @param age End of neonatal stage in days
#' @author Frank PG Princee
#' @family census
#' @export
#'
setNeonatalAge <- function(age=30.0) 
{
  neonatal_age <<- age
}

###
#' @title Set neontal age 
#' @return End of neonatal stage in days
#' @author Frank PG Princee
#' @family census
#' @export
#'
getNeonatalAge <- function() 
{
  return(neonatal_age)
}




###
#' @title Neonatal mortality
#' @author Frank PG Princee
#' @family census
#' @export

studbook.neonatalDeaths <- function(first=NULL,last=NULL) 
{
    
    neonatal.data <- studbook.read('neonatal')
    if (is.null(neonatal.data)) {
      stop("No neonatal mortality data.")
    }
    
    studbook.screenTitle('Neonatal mortality')
    frequency                      <- 1
    attr(neonatal.data,"interval") <- names(neonatal.data)[1]
    colnames(neonatal.data)        <- c('DATE','COUNT')  
    neonatal.data[,'DATE']         <- base::as.Date(neonatal.data[,'DATE'])
    period                         <- range(tis::year(neonatal.data[,'DATE']))
    
    #Create time serie
    neonatal.ts <- ts(data=neonatal.data[,'COUNT'],start=period[1],frequency=frequency)
   
    if (is.numeric(first)) {
      period[1] <- first
    }
    
    if (is.numeric(last))  {
      period[2] <- last
    }
    
    neonatal.ts <- window(neonatal.ts,start=period[1],end=period[2])
    
    if (studbook.plot()) {
      studbook.openOutput('neontal_death')
      plot(neonatal.ts, main="",type='l',xlab='Date',ylab='Individuals',
           lwd=1,lty='solid')
      studbook.title('neonatal deaths')
      studbook.closeOutput()
    }
    
    start_year <- start(neonatal.ts)
    end_year   <- end(neonatal.ts)
    
    death.ts  <- census.read('death',start_year[1],end_year[1]) 
    if (is.null(death.ts)) {
      stop("No data on deaths.")
    }
      
    
    death_rate <- data.frame("NEONATAL"=neonatal.ts,"DEATH" = death.ts[,'ALL'])
    death_rate <- ts(data=death_rate,start=start_year[1],frequency=1)
   
    census.rate(death_rate,'neonatal/total death rate','neonatal_rate')
      
    birth.data  <- census.read('birth',start_year[1],end_year[1]) 
    if (is.null(birth.data)) {
      stop("No data on births.")
    }
    death_rate <- data.frame("NEONATAL"=neonatal.ts,"BIRTH" = death.ts[,'ALL'])
    death_rate <- ts(death_rate,start=start_year[1],frequency=1)
    census.rate(death_rate,'neonatal/birth rate','neontal_birth')

}