###
# Package : studbookR
# Module  : studbook_project
# Copyright (c) 2012 Frank PG Princee, All rights reserved
#


###
#' @title Finds and selects available projects
#' @details This function searches for project directories (folders) in the
#' folder as with the function studbook.setPath(). Users can select these projects
#' from a (console) menu. 
#' @author Frank PG Princee
#' @return project name
#' @keywords internal
#
studbook.projects <- function()
{
  
  path <- paste(studbook.getPath())
  projects <- list.files(path,full.names=TRUE,recursive=FALSE)
  projects <- projects[file.info(projects)$isdir] # Only include directories
  
  if (length(projects) == 0) {
    return(NULL)
  }
  
  projects <- basename(projects)
  number   <- menu(projects,graphics = FALSE,title="Select project number (0=cancel):")
  
  if (number == 0) {
    return(NULL)
  }
  
  return(projects[number])
}


###
#' @title Extract biological data from PML project
#' @details The PML software stores biological data in XML format in the file
#' <project name>.biology.  
#' @author Frank PG Princee
#' @keywords internal
#
studbook.biology <- function()
{
  file_name    <- paste(studbook.getPath(),studbook.getName(),sep="/")
  file_name    <- paste0(file_name,'/',studbook.getName(),'.biology')
  
  if (file.exists(file_name)) {
    biology.tree <- XML::xmlTreeParse(file_name)
    return(XML::xmlRoot(biology.tree))
  } else {
    cat("No biological information on project")
  }
}