###
#' @title Survival function estimator for reccurent survival and fecundity data
#' @description \code{survival.recurrent} estimates survival and fecundity using the 
#' Pena, Strawderman and Hollander method  
#' @param survival.data survival data that corresponds with Survr object. 
#' @param subset subset of survival.data.
#' @param term string with fixed terms.
#' @param stratum field to stratify (default: NULL).
#' @param quantile for reccurent survival test (default 0.5).
#' @param recurrent_type type of estimator: \code{"pe"}: Pena-Strawderman-Hollander, 
#' \code{"wa"}: Wang-Chang or \code{"ML"}:MLE Frailty estimator (default:\code{"pe"}). 
#' @return \code{survfitr} object
#' @author Frank Princee
#' @keywords internal
#' @family survival
#' @seealso kaplan.meier, cox.regression
#' 
survival.recurrent <- function(survival.data,subset,term,stratum=NA,quantile=0.5,
                               recurrent_type=c('pe','wa','ML'))
{  
  
  recurrent_type <- match.arg(recurrent_type)
  formula.km <- paste("survival.object ~",term)
  
  if (!is.na(stratum)) {
    formula.km <- paste(formula.km,"+ strata(",stratum,")")
  }
  
  cat("Formula  :",formula.km,"\n\n")
  
  print(head(survival.data))
  survival.data$ID <- as.factor(survival.data$ID)
  survival.object  <- survrec::Survr(id=survival.data$ID,time=survival.data$TIME,event=survival.data$EVENT)
  
  recurrent.fit <- survrec::survfitr(as.formula(formula.km),data=survival.data,type=recurrent_type)
  difftest      <- survrec::survdiffr(as.formula(formula.km),data=survival.data,q=0.5,B=999)
  cat("[ Bootstrap ]\n")
  print(difftest)
  
  return(recurrent.fit)
}

