###
#' @title Create single or double line
#' @param n Number of replications
#' @param lstyle Character for line
#' @author Frank PG Princee
#' @family report
#' @keywords internal
#' 
createLine <- function(n,lstyle)
{
  line <- paste(replicate(n,lstyle),collapse="")
  return(line)
}

###
#' @title Change first character to upper case
#' @param string String(s)
#' @author Frank PG Princee
#' @family report
#' @keywords internal
#' 
firstCap <- function(string)
{
  for (i in 1:length(string)) {
     if (is.expression(string[i]) ) {
        next
     }
     string[i] <- tolower(string[i])
     string[i] <- paste0(toupper(substr(string[i], 1, 1)), 
                         substr(string[i], 2, nchar(string[i])))
  }
  return(string)
}

###
#' @title Print caption for figures
#' 
#' @param main_title Caption title
#' @param text Additional text
#' @return caption
#' @author Frank PG Princee
#' @family report
#' @keywords internal
#
studbook.caption <- function(main_title,text=NA)
{
  caption <- paste("Figure ",studbook.getFigure(),". ",main_title,".\n",sep='')
  if (!is.na(text)) {
    caption <- paste(caption,text,"\n",sep='')
  }
  
  if (studbook.isOption('output','draft')) {
    cat(caption,fill=TRUE,file=studbook.get("file_handle"))
  }
  return(caption)
}


###
#' @title Print main title and (optional) subtitle for figures
#' @details Creates title and increases figure number. The figure number
#' is included in the main_title. Titles are not printed when output is in 
#' "publish" mode.
#' @param main_title main figure title
#' @param sub_title sub title (default = NA)
#' @author Frank PG Princee
#' @family report
#' @keywords internal
#' 
studbook.title <- function(main_title,sub_title=NA)
{
  # Leave title from published reports  
  if (!studbook.isOption('output','publish') & studbook.plot() ) {
    if (!is.null(studbook.getFigure())) {
       new_title <- paste("[",studbook.getFigure(),"] ",sep="") 
       title(main=paste(new_title,main_title))
    } else {
       title(main=main_title)
    }
    
    if ( !is.na(sub_title) ) {
      title(sub=sub_title,cex.sub=0.8)
    }
    studbook.newFigure()  
  }
}




###
#' @title Shows main title on screen
#' @param main_title main title
#' @author Frank PG Princee
#' @family report
#' @keywords internal
#' 
studbook.screenTitle <- function(main_title)
{
  double_line <- createLine(50,"=")
  cat(double_line,"\n")
  cat(main_title,"\n")
  cat(double_line,"\n\n")
}


###
#' @title Shows section title on screen
#' @param section_title section title
#' @author Frank PG Princee
#' @family report
#' @keywords internal
#' 
studbook.screenSection <- function(section_title)
{
  single_line <- createLine(50,"-")
  cat(single_line,"\n")
  cat(section_title,"\n")
  cat(single_line,"\n")
}




