## ----include=FALSE-------------------------------------------------------
library(studbookR)
library(lme4)
tutorial()
studbook.set("figure",NULL)
studbook('animal')
studbookR:::phenotype.litter("SIZE")

## ----trait_menu,eval=FALSE-----------------------------------------------
#  
#  phenotype()
#  
#  ## 1: First age at reproduction
#  ## 2: Fitness
#  ## 3: Inter-birth interval
#  ## 4: Lifespan
#  ## 5: Litter day
#  ## 6: Litter size
#  ## 7: Litter sex-ratio
#  ## 8: Litter survived
#  
#  Selection: 6

## ----parent_offspring----------------------------------------------------
phenotype.regression(parent='sire',offspring='male') # Father-son regression

## ----repeatability, warnings=FALSE---------------------------------------
phenotype.repeatability()

## ----pedigree------------------------------------------------------------
pedigree.read()
tail(studbook.pedigree,3)

## ----REML1---------------------------------------------------------------
animalmodel.reml()

## ----REML2, eval=FALSE---------------------------------------------------
#  animalmodel.reml( "(1|animal) + SEX + (1|LITTER_ID)" )

## ----reset, include=FALSE------------------------------------------------
studbookR:::phenotype.litter("SIZE") # or use 
pedigree.read()

## ----MCMC1---------------------------------------------------------------
animalmodel.mcmc()

## ----MCMC_set, eval=FALSE------------------------------------------------
#  animalmodel.setFixed("SEX")                 # sex as fixed effect
#  animalmodel.setPrior("observed")            # prior based on observed phenotypic variance
#  animalmodel.setRandom("animal + LOCATION")  # individual and birth location
#  animalmodel.setRuns(25000,25,5000)          # iterations, thinning and burnin' period

## ----MCMC_rp-------------------------------------------------------------
animalmodel.setFixed("1")                   # no fixed effects
animalmodel.setPrior("observed")            # prior based on observed phenotypic variance
animalmodel.setRandom("ID")                 # individual ID's
animalmodel.mcmc()

