% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/studbookR_projection.R
\name{projection.leslie}
\alias{projection.leslie}
\title{Population projection based on Leslie matrix}
\usage{
projection.leslie(sex = c("female", "male", "unknown", "all"),
  field = c("OBSERVED", "MEAN", "LOWER", "UPPER"), season = c("pulse",
  "flow"), census = c("post", "pre"), date = "last", project.years = 25,
  stage.list = NULL, show_info = TRUE, sensitivity = FALSE,
  do_print = FALSE)
}
\arguments{
\item{sex}{Sex group; valid names are \code{"female","male","unknown","all"} 
(default: "female")}

\item{field}{text Data field for \eqn{q_x} and \eqn{m_x}: \code{"OBSERVED","MEAN","LOWER","UPPER"} as
used in PML output (default: "OBSERVED").}

\item{season}{Type of birth season: \code{"pulse"} or \code{"flow"} (default: \code{"pulse"})}

\item{census}{Type of census" \code{"post"} or \code{"pre"}-breeding (default: \code{"post"})}

\item{date}{Date of census with age distribution data in yyyymmdd format; alternatively
enter "first" or "last" available census data; "?" to select list.}

\item{project.years}{integer sequence of years e.g. 2014:2024 or total years e.g. 20}

\item{stage.list}{List with stage definitions}

\item{show_info}{Show matrix info (default: TRUE)}

\item{sensitivity}{Sensitivity and elasticity analyses (default: FALSE)}

\item{do_print}{Print matrix (default: FALSE)}
}
\details{
If data for timespan is provided then the timespan will be 0:25 
Age classes are grouped in stage groups for graphic purposes i.e. the population
projection is based on age classes, but results re-grouped in stages.
}
\examples{
\dontrun{
stage.list <- list(infant=0,juvenile=1,adult=2:10,senescent=11)
future.matrix(sex="female",field='MEAN',timespan=50,stage.list=stage.list,do_print=FALSE)
}
}
\author{
Frank PG Princee
}
\seealso{
create.stages

Other population projection: \code{\link{create.stages}},
  \code{\link{projection.arima}},
  \code{\link{projection.census}},
  \code{\link{projection.stochastic}}
}

