% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/studbookR_inbreeding.R
\name{studbook.lethaleqv}
\alias{studbook.lethaleqv}
\title{Compute and plot lethal equivalents}
\usage{
studbook.lethaleqv(sex = c("all", "female", "male", "unknown"),
  parents = c("none", "inbred", "dam", "sire", "both", "single", "all"),
  age = c(0, 30), method = c("mle", "lm", "glm", "glmRob", "glmer",
  "glmindv", "geeglm", "none"), link = c("logit", "log", "cloglog"),
  do_summary = FALSE)
}
\arguments{
\item{sex}{text \code{"all"}, \code{"female"}, \code{"male"} or \code{"unknown"} 
(default: \code{"all"}).}

\item{parents}{text Inbreeding status of parents: \code{"all"}, \code{"both"}, \code{inbred}, 
\code{dam},\code{sire},\code{"single"} and \code{"none"} (default: \code{"none"})}

\item{age}{Neonatal ages for fitness, chi-square test and Cox regression (default: c(0,30))}

\item{method}{One or methods: \code{"lm"}, \code{"mle"}, \code{"glm"}, \code{"glmer"}, 
\code{"glmindv"},\code{"glmglee"} and/or \code{"glmRob"} (default: \code{"mle"})}

\item{link}{Binomial link model: \code{"clogclog"}, 
\code{"log"} or \code{"logit"} in GLM (default: "logit")}

\item{do_summary}{Print summary of regression results (default:FALSE)}
}
\details{
\code{parents} refer to the inbreeding status of the parents:
- \code{"all"}: inbred and non-inbred parents  
- \code{"both"}: both parents are inbred, 
- \code{inbred}: at least one parent is inbred
- \code{dam}: dam inbred, sire noninbred 
- \code{sire}: sire inbred, dam noninbred
- \code{"single"}: single parent is inbred
- \code{"none"}: both parents are noninbred

\code{method} 
- \code{"lm"}: log linear model adjusted for zero survivals (groups)
- \code{"mle"}: maximum likelikhood estimation (groups)
- \code{"glm"}: generalised linear model (groups)
- \code{"glmer"}: mixed general linear model with litter as random effect (individuals)
- \code{"glmind"}: generalised linear model (individuals)
- \code{"geeglm"}: GEE version of generalised linear model (individuals)
- \code{"glmRob"}: Robust (sandwich) variance version of generalised linear model (litters) 
- \code{"none"}: Only plot observed data
}
\author{
Frank PG Princee
}
\seealso{
Other inbreeding: \code{\link{create.inbred}},
  \code{\link{inbreeding.depression}},
  \code{\link{inbreeding.level}},
  \code{\link{inbreeding.parents}},
  \code{\link{inbreeding.survival}},
  \code{\link{inbreeding.test}},
  \code{\link{lethaleqv.fit}},
  \code{\link{lethaleqv.geeglm}},
  \code{\link{lethaleqv.glmRob}},
  \code{\link{lethaleqv.glmer}},
  \code{\link{lethaleqv.glm}}, \code{\link{lethaleqv.lm}},
  \code{\link{lethaleqv.mle}},
  \code{\link{lethaleqv.plot}},
  \code{\link{lethaleqv.print}},
  \code{\link{studbook.inbreeding}}
}

