% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/studbookR_survival.R
\name{studbook.survival}
\alias{studbook.survival}
\title{Kaplan Meier Estimator and Cox regression for survival and fecundity}
\usage{
studbook.survival(analysis = c("survival", "fecundity", "firstbirth"),
  method = c("kaplan", "cox", "recurrent"), sex = c("all", "female", "male",
  "unknown"), unknown = c("exclude", "equal", "include"), group = "1",
  filter = list(param = NA, location = "BIRTHSITE", condition = NULL,
  prediction = NULL), stratum = NA, legend.title = NULL, plot.conf = TRUE,
  age = c(0, Inf), cluster = c("LITTER_ID", "BIRTHSITE", "DAM", "ID",
  "NONE"), rho = 0, alpha = 0.05, ymin = 0, percent = FALSE,
  summary = FALSE, verbose = TRUE)
}
\arguments{
\item{analysis}{Type of data to be analysed. Options are \code{"survival", "firstbirth", "fecundity"} (default: \code{"survival"}.}

\item{method}{Analysis method to be used: \code{"cox", "kaplan","recurrent"} (default: \code{"kaplan"})}

\item{sex}{Sex group to analyse. Options are \code{"all", "female", "male", "unknown"} (default: \code{"all"}).}

\item{unknown}{text. Possible values are \code{"exclude","equal","include"} to
exclude individuals of unknown sex; distribute equally over 
males and females or include as unknown (default:\code{"exclude"}).}

\item{group}{text Name of group(s) to be compared. The value "1" means no groups are compared (default: "1")}

\item{filter}{list with parameter and filter conditions. (default: param=NA,location='BIRTHSITE', 
condition=NA).}

\item{stratum}{Field to stratify e.g. "BIRTHSITE" (default:NA)}

\item{legend.title}{Title for legend (default: NULL)}

\item{plot.conf}{Plot confidence interval (up to 2 strata) (default:TRUE)}

\item{age}{Range of  monitoring ages (in days). Living individuals beyond the last age 
are censored. A single value refer to the start age. (default: c(0,Inf) )}

\item{cluster}{Field to cluster in Cox PH analysis. Options are \code{"BIRTHSITE", "DAM","ID", 
"LITTER_ID", "NONE"} (default: \code{"LITTER_ID"} when twins are observed.).}

\item{rho}{The \code{rho}value in the G-rho family of Harington and Fleming (1982) test.
\code{rho=0} is the log-rank or Mantel-Haenszel test, \code{rho=1} is the Peto & Peto 
modification of the Gehan-Wilcoxon test. The latter is more approperiate for early deaths.
(default: 0)}

\item{alpha}{Significance level (default: 0.05)}

\item{ymin}{minimum of Y-scale (default: 0)}

\item{percent}{\code{TRUE}: plot survival as percentage}

\item{summary}{logical TRUE: print summary}

\item{verbose}{logical TRUE: show results}

\item{distribution}{Assumed distribution of the y value (=age)}
}
\description{
\code{studbook.survival} estimates survival and fecundity using the 
Kaplan-Meier Product Estimator and/or Cox's Proportional Hazards Regression Model
}
\details{
Age interval is inclusive i.e. [\code{age[1]},\code{age[2]}]
Cox automatically adds cluster LITTER_ID when twin, triplets etc. exist

The following data groups can optionally be analysed: 
\tabular{lllll}{
                \tab \strong{filter}\cr
\strong{group}  \tab \strong{param}  \tab \strong{condition} \tab \strong{location} \tab \strong{predictions} \cr
"ALTITUDE"      \tab \cr
"BREEDER"       \tab \cr
"CLIMATE"       \tab "koeppen", "thermal" \tab \tab "BIRTHSITE", "LOCATION"\cr
"COHORT"        \tab                      \tab empty: each year; list(c(1978,1988),c(1989,2008)) \cr
"INBRED"        \tab empty: F > 0; = F; \tab empty; \tab \cr
"G"             \tab \cr
"LITTER_SIZE"   \tab \cr
"PRECIPITATION" \tab \cr
"REARING"       \tab \cr
"SEX"           \tab \cr 
"TAXON"         \tab \cr
"TEMPERATURE"   \tab \cr 
}
}
\note{
The function survdiff does not accept left truncated data
}
\author{
Frank Princee
}
\seealso{
Other survival: \code{\link{equalCohorts}},
  \code{\link{is.recurrent}}, \code{\link{is.singleton}},
  \code{\link{survival.censorAge}},
  \code{\link{survival.cumulativeHazard}},
  \code{\link{survival.filter}},
  \code{\link{survival.getStratum}},
  \code{\link{survival.inbred}},
  \code{\link{survival.koeppen}},
  \code{\link{survival.lastRecord}},
  \code{\link{survival.litters}},
  \code{\link{survival.plot}},
  \code{\link{survival.recurrent}},
  \code{\link{survival.settings}},
  \code{\link{survival.thermal}},
  \code{\link{survival.unknownSex}},
  \code{\link{survival.worldclim}}
}

